@@ -578,7 +578,7 @@ class MultiLayerNet:
 
             target_layer = list(self.layers.items())[layer_idx][1]
 
-            print(layer_idx, param_kind, target_layer)
+            # print(layer_idx, param_kind, target_layer)
 
             if param_kind == "W":
                 target_layer.W = param_value
